import React, { PureComponent } from "react";
import "pdfjs-dist/web/pdf_viewer.css";
import "../style/pdf_viewer.css";
import "../style/PdfHighlighter.css";
import { T_Position, T_ScaledPosition, T_Highlight, T_Scaled, T_LTWH, T_EventBus, T_PDFJS_Viewer, T_PDFJS_Document, T_PDFJS_LinkService } from "../types";
declare type T_ViewportHighlight<T_HT> = {
    position: T_Position;
} & T_HT;
declare type State<T_HT> = {
    ghostHighlight: {
        position: T_ScaledPosition;
        content?: {
            image: string;
        };
    } | undefined | null;
    isCollapsed: boolean;
    range: Range | undefined | null;
    tip: {
        highlight: T_ViewportHighlight<T_HT>;
        callback: (highlight: T_ViewportHighlight<T_HT>) => React.ReactElement;
    } | undefined | null;
    tipPosition: T_Position | null;
    tipChildren: React.ReactElement | null | undefined;
    isAreaSelectionInProgress: boolean;
    scrolledToHighlightId: string;
};
declare type Props<T_HT> = {
    highlightTransform: (highlight: T_ViewportHighlight<T_HT>, index: number, setTip: (highlight: T_ViewportHighlight<T_HT>, callback: (highlight: T_ViewportHighlight<T_HT>) => React.ReactElement) => void, hideTip: () => void, viewportToScaled: (rect: T_LTWH) => T_Scaled, screenshot: (position: T_LTWH) => string, isScrolledTo: boolean) => React.ReactElement;
    highlights: Array<T_HT>;
    onScrollChange: () => void;
    scrollRef: (scrollTo: (highlight: T_Highlight) => void) => void;
    pdfDocument: T_PDFJS_Document;
    pdfScaleValue: string;
    onSelectionFinished: (position: T_ScaledPosition, content: {
        text?: string;
        image?: string;
    }, hideTipAndSelection: () => void, transformSelection: () => void) => React.ReactElement;
    enableAreaSelection: (event: MouseEvent) => boolean;
};
declare class PdfHighlighter extends PureComponent<Props<T_Highlight>, State<T_Highlight>> {
    static defaultProps: {
        pdfScaleValue: string;
    };
    state: State<T_Highlight>;
    eventBus: T_EventBus;
    linkService: T_PDFJS_LinkService;
    viewer: T_PDFJS_Viewer | undefined;
    resizeObserver: ResizeObserver | null;
    containerNode: HTMLDivElement | undefined | null;
    unsubscribe: () => void;
    constructor(props: Props<T_Highlight>);
    componentDidMount(): void;
    attachRef: (ref: HTMLDivElement | undefined | null) => void;
    componentDidUpdate(prevProps: Props<T_Highlight>): void;
    init(): void;
    componentWillUnmount(): void;
    findOrCreateHighlightLayer(page: number): Element | null;
    groupHighlightsByPage(highlights: Array<T_Highlight>): {
        [pageNumber: string]: Array<T_Highlight>;
    };
    showTip(highlight: T_ViewportHighlight<T_Highlight>, content: React.ReactElement): void;
    scaledPositionToViewport({ pageNumber, boundingRect, rects, usePdfCoordinates, }: T_ScaledPosition): T_Position;
    viewportPositionToScaled({ pageNumber, boundingRect, rects, }: T_Position): T_ScaledPosition;
    screenshot(position: T_LTWH, pageNumber: number): string;
    renderHighlights(nextProps?: Props<T_Highlight>): void;
    hideTipAndSelection: () => void;
    setTip(position: T_Position, inner: React.ReactElement): void;
    renderTip: () => JSX.Element | null;
    onTextLayerRendered: () => void;
    scrollTo: (highlight: T_Highlight) => void;
    onDocumentReady: () => void;
    onSelectionChange: () => void;
    onScroll: () => void;
    onMouseDown: (event: MouseEvent) => void;
    handleKeyDown: (event: KeyboardEvent) => void;
    afterSelection: () => void;
    debouncedAfterSelection: () => void;
    toggleTextSelection(flag: boolean): void;
    handleScaleValue: () => void;
    debouncedScaleValue: () => void;
    render(): JSX.Element;
}
export default PdfHighlighter;
